<div class="container">
    <div class="row">
        <div class="page-header">
            <h4><?= $this->lang->line('Import completed') ?></h4>
        </div>
    </div>
    <div class="row">
        <table class="table table-striped">
            <thead>
            <tr>
                <th><?= $this->lang->line('Result') ?></th>
                <th><?= $this->lang->line('Rows') ?></th>
            </tr>
            </thead>
            <tbody>
            <?php foreach ($stat as $res => $count) : ?>
                <tr>
                    <td><?= ucfirst($res) ?></td>
                    <td><?= $count ?></td>
                </tr>
            <?php endforeach; ?>
            </tbody>
        </table>
    </div>
</div>