<div class="container">
    <div class="row">
        <div class="page-header">
            <h4><?= $this->lang->line('Select xlsx file and press "Next" button') ?></h4>
        </div>
    </div>
    <div class="row">
        <?= form_open_multipart('', ['class' => 'form-vertical']) ?>
        <div class="control-group">
            <input type="file" name="userfile" id="userfile">
        </div>
        <?php if (!empty($error)) : ?>
            <div class="alert alert-error">
                <button type="button" class="close" data-dismiss="alert">×</button><?= $error ?>
            </div>
        <?php endif; ?>
        <div class="form-actions">
            <input type="submit" class="btn btn-large btn-primary" name="next" value="Next">
        </div>
        <?= form_close(); ?>
    </div>
</div>